pub struct RecordIter<'cursor, 'input> {
pub id: u64,
/* private fields */
}Expand description
Data records consist of a record code and a number of (up to) 64-bit integer values
The interpretation of the code and values is application specific and may vary between different block types.
Fields
id: u64Record code
Implementations
Sourceimpl<'cursor, 'input> RecordIter<'cursor, 'input>
impl<'cursor, 'input> RecordIter<'cursor, 'input>
pub fn payload(&mut self) -> Result<Option<Payload>, Error>
pub fn u64(&mut self) -> Result<u64, Error>
pub fn nzu64(&mut self) -> Result<Option<NonZero<u64>>, Error>
pub fn i64(&mut self) -> Result<i64, Error>
pub fn u16(&mut self) -> Result<u16, Error>
pub fn u32(&mut self) -> Result<u32, Error>
pub fn nzu32(&mut self) -> Result<Option<NonZero<u32>>, Error>
pub fn u8(&mut self) -> Result<u8, Error>
pub fn try_from<U: TryFrom<u64>, T: TryFrom<U>>(&mut self) -> Result<T, Error>
pub fn try_next_from<U: TryFrom<u64>, T: TryFrom<U>>( &mut self, ) -> Result<Option<T>, Error>
pub fn nzu8(&mut self) -> Result<Option<NonZero<u8>>, Error>
pub fn bool(&mut self) -> Result<bool, Error>
Sourcepub fn range(&mut self) -> Result<Range<usize>, Error>
pub fn range(&mut self) -> Result<Range<usize>, Error>
Reads start and len into Rust’s start..end
pub fn blob(&mut self) -> Result<&'input [u8], Error>
pub fn array(&mut self) -> Result<Vec<u64>, Error>
Sourcepub fn string_utf8(&mut self) -> Result<String, Error>
pub fn string_utf8(&mut self) -> Result<String, Error>
Read remainder of the fields as string chars.
Interpret data as UTF-8. The string may contain NUL terminator, depending on context.
Sourcepub fn string(&mut self) -> Result<Vec<u8>, Error>
pub fn string(&mut self) -> Result<Vec<u8>, Error>
Read remainder of the fields as string chars
The strings are just binary blobs. LLVM doesn’t guarantee any encoding. The string may contain NUL terminator, depending on context.
Sourcepub fn zstring(&mut self) -> Result<String, Error>
pub fn zstring(&mut self) -> Result<String, Error>
Zero-terminated string, assumes latin1 encoding
Sourcepub fn debug_abbrev_id(&self) -> Option<u32>
pub fn debug_abbrev_id(&self) -> Option<u32>
Internal ID of this record’s abbreviation, if any.
This is intended only for debugging and data dumps. This isn’t a stable identifier, and may be block-specific.