pub struct BlockIter<'global_state, 'input> {
pub id: u32,
/* private fields */
}Expand description
Iterator content directly in a block
Fields
id: u32ID of the block being iterated
Implementations
Sourceimpl<'global_state, 'input> BlockIter<'global_state, 'input>
impl<'global_state, 'input> BlockIter<'global_state, 'input>
pub fn next_record<'parent>( &'parent mut self, ) -> Result<Option<RecordIter<'parent, 'input>>, Error>
Sourcepub fn try_next<'parent>(
&'parent mut self,
) -> Result<Option<BlockItem<'parent, 'input>>, Error>
pub fn try_next<'parent>( &'parent mut self, ) -> Result<Option<BlockItem<'parent, 'input>>, Error>
Returns the next item (block or record) in this block
Sourcepub fn debug_abbrev_width(&self) -> u8
pub fn debug_abbrev_width(&self) -> u8
Bit width of abbreviation IDs in this block.
This is an implementation detail, intended only for debugging or data dumps.
Sourcepub fn debug_data_len(&self) -> Option<usize>
pub fn debug_data_len(&self) -> Option<usize>
Valid only before any record or subblock has been read. This is the block size in bytes.
This is an implementation detail, intended only for debugging or data dumps.