Module values

Module values 

Flags and values found in records From the LLVM Project, under the Apache License v2.0 with LLVM Exceptions

Structs

Alignment
LLVM bitcode encodes alignment as log2(alignment) + 1
CallMarkersFlags
Markers and flags for call instruction
FCmpPredicate
Floating-point comparison predicates
FastMathFlags
GEPFlags
GetElementPtrOptionalFlags
InlineAsmFlags
OverflowFlags
OverflowingBinaryOperatorOptionalFlags

Enums

AddressSpace
Address spaces identify different memory regions. The default address space is 0.
AtomicOrdering
Encoded AtomicOrdering values.
AttrKind
BinOpcode
These are values used in the bitcode files to encode which binop a CST_CODE_CE_BINOP refers to.
BinOpcodeFlags
Combines the opcode with its appropriate flags
CallConv
CastOpcode
These are values used in the bitcode files to encode which cast a CST_CODE_CE_CAST refers to.
CmpPredicate
Comparison predicate that can be either floating-point or integer
ComdatSelectionKind
COMDATSELECTIONKIND enumerates the possible selection mechanisms for COMDAT sections.
DebugEmissionKind
DICompileUnit::DebugEmissionKind
DebugNameTableKind
DICompileUnit::DebugNameTableKind
DllStorageClass
FuncletPad
ICmpPredicate
CmpInst::Predicate in InstrTypes.h
Linkage
These are bitcode-specific values, different from C++ enum
PreemptionSpecifier
GlobalValue::PreemptionSpecifier
RmwOperation
Atomic read-modify-write operations
ThreadLocalMode
GlobalValue::ThreadLocalMode
UnaryOpcode
Unary Opcodes
UnnamedAddr
GlobalValue::UnnamedAddr
Visibility
GlobalValue::VisibilityTypes

Type Aliases

OverflowingBinaryOperatorOptionalFlags
TruncInstOptionalFlags