#[repr(u8)]pub enum UnnamedAddr {
None = 0,
Global = 1,
Local = 2,
}Expand description
GlobalValue::UnnamedAddr
Variants
None = 0
The address of the global is significant
Global = 1
The address of the global is not significant, but the global cannot be merged with other globals
Local = 2
The address of the global is not significant, and the global can be merged with other globals