Flags and values found in records From the LLVM Project, under the Apache License v2.0 with LLVM Exceptions
Structs
- Alignment
- LLVM bitcode encodes alignment as
log2(alignment) + 1 - Call
Markers Flags - Markers and flags for call instruction
- FCmp
Predicate - Floating-point comparison predicates
- Fast
Math Flags - GEPFlags
GetElementPtrOptionalFlags- Inline
AsmFlags - Overflow
Flags OverflowingBinaryOperatorOptionalFlags
Enums
- Address
Space - Address spaces identify different memory regions. The default address space is 0.
- Atomic
Ordering - Encoded
AtomicOrderingvalues. - Attr
Kind - BinOpcode
- These are values used in the bitcode files to encode which
binop a
CST_CODE_CE_BINOPrefers to. - BinOpcode
Flags - Combines the opcode with its appropriate flags
- Call
Conv - Cast
Opcode - These are values used in the bitcode files to encode which
cast a
CST_CODE_CE_CASTrefers to. - CmpPredicate
- Comparison predicate that can be either floating-point or integer
- Comdat
Selection Kind - COMDATSELECTIONKIND enumerates the possible selection mechanisms for COMDAT sections.
- Debug
Emission Kind DICompileUnit::DebugEmissionKind- Debug
Name Table Kind DICompileUnit::DebugNameTableKind- DllStorage
Class - Funclet
Pad - ICmp
Predicate CmpInst::PredicateinInstrTypes.h- Linkage
- These are bitcode-specific values, different from C++ enum
- Preemption
Specifier GlobalValue::PreemptionSpecifier- RmwOperation
- Atomic read-modify-write operations
- Thread
Local Mode GlobalValue::ThreadLocalMode- Unary
Opcode - Unary Opcodes
- Unnamed
Addr GlobalValue::UnnamedAddr- Visibility
GlobalValue::VisibilityTypes