#[non_exhaustive]#[repr(u8)]pub enum Linkage {
Show 20 variants
External = 0,
WeakAnyOld = 1,
Appending = 2,
Internal = 3,
LinkOnceAnyOld = 4,
DllImport = 5,
DllExport = 6,
ExternWeak = 7,
Common = 8,
Private = 9,
WeakOdrOld = 10,
LinkOnceOdrOld = 11,
AvailableExternally = 12,
LinkerPrivate = 13,
LinkerPrivateWeak = 14,
LinkOnceOdrAutoHide = 15,
WeakAny = 16,
WeakOdr = 17,
LinkOnceAny = 18,
LinkOnceOdr = 19,
}Expand description
These are bitcode-specific values, different from C++ enum
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
External = 0
Externally visible function
WeakAnyOld = 1
Keep one copy of named function when linking (weak) Old value with implicit comdat.
Appending = 2
Special purpose, only applies to global arrays
Internal = 3
Rename collisions when linking (static functions).
LinkOnceAnyOld = 4
Keep one copy of function when linking (inline) Old value with implicit comdat.
DllImport = 5
Externally visible function Obsolete DLLImportLinkage
DllExport = 6
Externally visible function Obsolete DLLExportLinkage
ExternWeak = 7
ExternalWeak linkage
Common = 8
Tentative definitions.
Private = 9
Like Internal, but omit from symbol table.
WeakOdrOld = 10
Same, but only replaced by something equivalent. Old value with implicit comdat.
LinkOnceOdrOld = 11
Same, but only replaced by something equivalent. Old value with implicit comdat.
AvailableExternally = 12
Available for inspection, not emission.
LinkerPrivate = 13
Like Internal, but omit from symbol table. Obsolete LinkerPrivateLinkage
LinkerPrivateWeak = 14
Like Internal, but omit from symbol table. Obsolete LinkerPrivateWeakLinkage
LinkOnceOdrAutoHide = 15
Externally visible function Obsolete LinkOnceODRAutoHideLinkage
WeakAny = 16
Keep one copy of named function when linking (weak)
WeakOdr = 17
Same, but only replaced by something equivalent.
LinkOnceAny = 18
Keep one copy of function when linking (inline)
LinkOnceOdr = 19
Same, but only replaced by something equivalent.